"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Csrf = /** @class */ (function () {
    function Csrf(csrfHeader, getToken) {
        this.getToken = getToken || Csrf.getTokenDefault;
        this.csrfHeader = csrfHeader || 'X-CSRF-TOKEN';
    }
    Csrf.prototype.authorize = function (request) {
        return request([this.csrfHeader, this.getToken()]);
    };
    // 1) Look for csrf_token cookie
    // "csrf_token={{ csrf_token() }}; Path=/; Domain=.procore.com; SameSite=Strict; Secure=true;"
    // 2) Look for csrf-token meta tag
    // <head>
    //   <meta name="csrf-token" content="{{ csrf_token() }}">
    // </head>
    // 3) Return ""
    // https://cheatsheetseries.owasp.org/cheatsheets/Cross-Site_Request_Forgery_Prevention_Cheat_Sheet.html
    Csrf.getTokenDefault = function () {
        var cookieToken = document.cookie.match(/(?:^|;)\s*csrf_token\s*=\s*([^;]+)/);
        if (cookieToken) {
            return decodeURIComponent(cookieToken[cookieToken.length - 1]);
        }
        var metaTokenCtr = window.document.querySelector('meta[name="csrf-token"]');
        return (metaTokenCtr && metaTokenCtr.getAttribute('content')) || '';
    };
    return Csrf;
}());
function csrf(csrfHeader, getToken) {
    return new Csrf(csrfHeader, getToken);
}
exports.default = csrf;
